Informes | OiRA

Temes

# Informes

Podeu utilitzar un informe per:

- Aportar proves a les autoritats competents.
- Transmetre informació a les persones afectades (treballadors, delegats de prevenció, empresaris, experts en seguretat i salut en el treball, etc.).
- Supervisar i avaluar si s’han adoptat les mesures necessàries.
- Registrar qualsevol revisió si les circumstàncies canvien (màquines noves, treballadors nous, com a resultat de les conclusions de qualsevol investigació d’accidents, etc.).

Podeu desar l’informe en el vostre ordinador i imprimir-lo. També el podeu modificar o afegir-hi més informació. Tingueu en compte que els canvis efectuats en un informe que heu descarregat NO es desen a l’eina OiRA.

## Tipus d’informe

Hi ha diferents tipus d’informes disponibles per a diferents finalitats. La selecció dels informes disponibles per a les eines específiques depèn de les decisions adoptades pel soci o el desenvolupador nacional de l’eina OiRA.

Informes disponibles

### Informe complet

Format: Word/Office Open XML (.docx). Es pot editar després d’haver-lo descarregat.

Proporciona: tota la informació i les entrades que hi heu consignat durant el procés d’avaluació de riscos.

Utilitzeu l’informe per:

- Aportar proves de l’avaluació de riscos a les autoritats competents (Inspecció de Treball).

### Pla d’acció

Formato: Excel/Office Open XML (.xlsx). Es pot editar després d’haver-lo descarregat.

Proporciona: informació sobre totes les mesures que heu decidit adoptar.

Utilitzeu l’informe per:

- Fer un seguiment actiu de l’aplicació de les mesures per les quals hàgiu optat.
- Gestionar els riscos en el lloc de treball (tasques específiques, coneixements especialitzats, responsabilitats, terminis).

### Descripció general dels riscos

Format: format de document portàtil (.pdf). No es pot editar després d’haver-lo descarregat.

Proporciona: una visió general dels riscos identificats.

Utilitzeu l’informe per:

- Obtenir una visió general ràpida de l’estat dels riscos en el vostre centre de treball.
- Transmetre informació a les persones interessades.
- Supervisar si s’estan tractant de manera adequada els riscos i les mesures.

### Visió general de les mesures

Formato: format de document portàtil (.pdf). No es pot editar després d’haver-lo descarregat.

Proporciona: una visió general ràpida de les mesures que s’han d’aplicar.

Utilitzeu l’informe per:

- Obtenir una visió general ràpida de l’estat de les mesures que heu decidit aplicar.
- Transmetre informació a les persones interessades.
- Supervisar si els riscos i les mesures s’estan tractant de manera adequada.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More